@@ -1,13 +1,14 @@
 package CMS::Drupal::Modules::MembershipEntity;
-$CMS::Drupal::Modules::MembershipEntity::VERSION = '0.91';
-
+$CMS::Drupal::Modules::MembershipEntity::VERSION = '0.92';
 # ABSTRACT: Perl interface to Drupal MembershipEntity entities
 
+use strict;
+use warnings;
+
 use Moo;
 use Types::Standard qw/ :all /;
 use Time::Local;
-use Carp qw/ carp croak confess /;
-use Data::Dumper;
+use Carp qw/ carp croak /;
 
 use CMS::Drupal::Modules::MembershipEntity::Membership;
 use CMS::Drupal::Modules::MembershipEntity::Term;
@@ -20,27 +21,31 @@ sub fetch_memberships {
   my $self = shift;
 
   ## We accept a list of mids as an optional parameter
-  my $mids = [ @_ ];
+  my @mids = @_;
 
   my $WHERE = ' ';
  
-  if ( $mids ) {
-    if ( scalar @{ $mids } < 1 ) {
-      carp 'Empty arrayref passed to fetch_memberships() ... returning all Memberships';
+  if ( @mids ) {
+    if ( scalar @mids < 1 ) {
+      carp 'Empty array passed to fetch_memberships() ... returning all Memberships';
     }
 
-    for (@$mids) {
-      # Let's be real strict about what we try to pass in to the DBMS
-      confess 'FATAL: Invalid mid (must be all ASCII digits).'
-        unless /^[0-9]+$/;
+    if ( ! grep { /all/ } @mids ) {
+       # ^ in that case no WHERE clause
+
+      for ( @mids ) {
+        # Let's be real strict about what we try to pass in to the DBMS
+        croak 'FATAL: Invalid mid (must be all ASCII digits).'
+          unless /^[0-9]+$/;
       
-      $WHERE = 'WHERE ';
-      $WHERE .= "mid = '$_' OR " for @$mids;
-      $WHERE =~ s/ OR $//;
+        $WHERE = 'WHERE ';
+        $WHERE .= "mid = '$_' OR " for @mids;
+        $WHERE =~ s/ OR $//;
+      }
     }
   }
 
-  my $prefix = $self->{'prefix'} || '';
+  my $prefix = ( $self->{'prefix'} || '' );
 
   my $temp;
   my $memberships;
@@ -56,7 +61,7 @@ sub fetch_memberships {
   $sth->execute;
   
   my $results = $sth->fetchall_hashref('mid');
-  foreach my $mid (keys( %$results )) {
+  foreach my $mid (keys( %{ $results } )) {
     $temp->{ $mid } = $results->{ $mid };
   }
   
@@ -75,17 +80,27 @@ sub fetch_memberships {
   my %term_count; # used to track array position of Terms
 
   while( my $row = $sth2->fetchrow_hashref ) {
-    ## Shouldn't be, but is, possible to have a Term with no start or end
+    
+    ## Shouldn't be, but is, possible to have a Term with no
+    ## start or end date
     if ( not defined $row->{'start'} or not defined $row->{'end'} ) {
-      carp "MISSING DATE: tid< $row->{'tid'} > " .
-           "(uid< $temp->{ $row->{'mid'} }->{'uid'} >) has no start " .
+      carp "MISSING DATE: tid[ $row->{'tid'} ] " .
+           "(uid[ $temp->{ $row->{'mid'} }->{'uid'} ]) has no start " .
            "or end date defined. Skipping ...";
       next;
     }
 
+    ## Shouldn't be, but is, possible to have a Term with no
+    ## corresponding Memberships
+    if ( not defined $temp->{ $row->{'mid'} } ) {
+      carp "TERM WITH NO MEMBERSHIP: tid[ $row->{'tid'} ] " .
+           "has no corresponding Membership. Skipping ...";
+      next;
+    }
+
     ## convert the start and end to unixtime
     for (qw/ start end /) {
-      my @datetime = reverse (split /[-| |:]/, $row->{ $_ });
+      my @datetime = reverse ( split /[-| |:]/, $row->{ $_ } );
       $datetime[4]--;
       $row->{ $_ } = timelocal( @datetime );
     } 
@@ -97,20 +112,20 @@ sub fetch_memberships {
     ## Instantiate a MembershipEntity::Term object for each
     ## Term now that we have the data
     my $term = CMS::Drupal::Modules::MembershipEntity::Term->new( $row );
-    $temp->{ $row->{'mid'} }->{ 'terms' }->{ $row->{'tid'} } = $term;
+    $temp->{ $row->{'mid'} }->{'terms'}->{ $row->{'tid'} } = $term;
   }
 
   ## Instantiate a MembershipEntity::Membership object for each
   ## Membership now that we have the data
-  foreach my $mid( keys( %$temp )) {
+  foreach my $mid(keys( %{ $temp } )) {
     
     ## Shouldn't be, but is, possible to have a Membership with no Term
     if (not defined $temp->{ $mid }->{'terms'}) {
-      carp "MISSING TERM: mid< $mid > (uid< $temp->{ $mid }->{'uid'} >) " .
+      carp "MISSING TERM: mid[ $mid ] (uid[ $temp->{ $mid }->{'uid'} ]) " .
            "has no Membership Terms. Skipping ...";
       next;
     }
-    
+
     $memberships->{ $mid } =
     CMS::Drupal::Modules::MembershipEntity::Membership->new( $temp->{ $mid } );
   }
@@ -134,7 +149,7 @@ CMS::Drupal::Modules::MembershipEntity - Perl interface to Drupal MembershipEnti
 
 =head1 VERSION
 
-version 0.91
+version 0.92
 
 =head1 SYNOPSIS
 
@@ -142,10 +157,7 @@ version 0.91
 
   my $ME = CMS::Drupal::Modules::MembershipEntity->new( { dbh => $dbh } );
 
-  my $hashref = $ME->fetch_memberships;
-
-  # or:
-  my $hashref = $ME->fetch_memberships( 123, 456, 789 );
+  my $hashref = $ME->fetch_memberships( 'all' );
 
   # or:
   my $hashref = $ME->fetch_memberships( 123 );
@@ -153,11 +165,11 @@ version 0.91
   # or:
   my $hashref = $ME->fetch_memberships( @list );
  
-  foreach my $mid ( sort keys %{$hashref} ) {
+  foreach my $mid ( sort keys %{ $hashref } ) {
     my $mem = $hashref->{ $mid };
    
-    print $mem->{'type'};
-    &send_newsletter( $mem->{'uid'} ) if $mem->active;
+    print $mem->type;
+    send_newsletter( $mem->uid ) if $mem->active;
    
     # etc ...
   }
@@ -168,9 +180,9 @@ version 0.91
 
 This method returns a hashref containing Membership objects indexed by B<mid>.
 
-When called with no arguments, the hashref contains all Memberships in the 
-Drupal database, which might be too much for your memory if you have lots
-of them.
+When called with the argument 'all', the hashref contains all Memberships in 
+the Drupal database, which might be too much for your memory if you have 
+lots of them.
 
 When called with an array containing B<mid>s, the hashref will contain an 
 object for each mid in the array.
@@ -185,7 +197,10 @@ object for each mid in the array.
   my $hashref = $ME->fetch_memberships( @list );
 
   # Fetch all your Memberships
-  my $hashref = $ME->fetch_memberships;
+  my $hashref = $ME->fetch_memberships('all');
+
+  # Same thing but with a warning
+  my $hashref = $ME->fetch_memberships();
 
 IMPORTANT: If you have bad records in your Drupal database, the module will
 print a warning and skip the record. This happens when there are no Terms
@@ -218,7 +233,7 @@ module where they are documented completely.
 
 You can directly access all the Membership's attributes as follows:
 
-  $mem->{ attr_name }
+  $mem->attr_name
 
 Where attr_name is one of:
 
@@ -230,7 +245,7 @@ Where attr_name is one of:
   created
   changed
 
-There is also another attribute `terms`, which contains an hashref of Term
+There is also another attribute 'terms', which contains a hashref of Term
 objects, indexed by B<tid>. Each Term can be accessed by the methods described
 in the Membership Terms section below.
 
@@ -238,8 +253,38 @@ in the Membership Terms section below.
 
 Once you have the Membership object, you can call some methods on it:
 
-  print "User $mem->{'uid'} is in good standing" if $mem->is_active;
-  print "User $mem->{'uid'} has already renewed" if $mem->has_renewal;
+  print 'User ' . $mem->uid . ' is in good standing' if $mem->is_active;
+  print $mem->mid . ' has already renewed' if $mem->has_renewal;
+
+Methods are:
+
+=over 4
+
+=item *
+
+is_active()
+
+=item *
+
+is_expired()
+
+=item *
+
+is_cancelled()
+
+=item *
+
+is_pending()
+
+=item *
+
+has_renewal()
+
+=item *
+
+current_was_renewal()
+
+=back
 
 =head2 Membership Terms
 
@@ -247,7 +292,7 @@ This module uses CMS::Drupal::Modules::MembershipEntity::Term so you
 don't have to. The methods described below are actually in the latter
 module where they are documented compeletely.
 
-  while ( my ($tid, $term) = each %{$mem->{'terms'}} ) {
+  while ( my ($tid, $term) = each %{ $mem->{'terms'} } ) {
     # do something ...
   }
 
@@ -255,7 +300,7 @@ module where they are documented compeletely.
 
 You can directly access all the Term's attributes as follows:
 
-  $term->{ attr_name }
+  $term->attr_name;
 
 Where attr_name is one of:
 
@@ -272,13 +317,30 @@ the Term is a renewal, etc.
 
 =head3 Membership Term methods
 
-  print "$term->{'tid'} is active" if $term->is_active;
+  print 'This is a live one' if $term->is_current;
+  push @renewals, $term->tid if $term->was_renewal;
 
-  print "This is a live one" if $term->is_current;
+Methods are:
 
-  print "$mem->{'uid'} has a prepaid renewal" if $term->is_future;
+=over 4
 
-  print "$mem->{'uid'} is a repeat customer" if $term->was_renewal;
+=item *
+
+is_active()
+
+=item *
+
+is_current()
+
+=item *
+
+is_future()
+
+=item *
+
+was_renewal()
+
+=back
 
 =head1 SEE ALSO
 
