@@ -1,5 +1,5 @@
 package CMS::Drupal::Modules::MembershipEntity::Membership;
-$CMS::Drupal::Modules::MembershipEntity::Membership::VERSION = '0.91';
+$CMS::Drupal::Modules::MembershipEntity::Membership::VERSION = '0.92';
 # ABSTRACT: Perl interface to a Drupal MembershipEntity membership
 
 use strict;
@@ -50,7 +50,7 @@ sub has_renewal {
   my $self = shift;
   $self->{'_has_renewal'} = 0;
   foreach my $term ( values %{ $self->{'terms'} } ) {
-    $self->{'_has_renewal'}++ if ($term->is_future and $term->is_active);
+    $self->{'_has_renewal'} = 1 if ($term->is_future and $term->is_active);
   }
   return $self->{'_has_renewal'};
 }
@@ -60,7 +60,7 @@ sub current_was_renewal {
   my $self = shift;
   $self->{'_current_was_renewal'} = 0;
   foreach my $term ( values %{ $self->{'terms'} } ) {
-    $self->{'_current_was_renewal'}++ if ($term->is_current && $term->was_renewal);
+    $self->{'_current_was_renewal'} = 1 if ($term->is_current and $term->was_renewal);
   }
   return $self->{'_current_was_renewal'};
 }
@@ -80,7 +80,7 @@ CMS::Drupal::Modules::MembershipEntity::Membership - Perl interface to a Drupal
 
 =head1 VERSION
 
-version 0.91
+version 0.92
 
 =head1 SYNOPSIS
 
@@ -132,7 +132,7 @@ Note: This module does not currently create or edit Memberships.
 
 This module is not designed to be called directly, although it can be. This module is called by L<CMS::Drupal::Modules::MembershipEntity|CMS::Drupal::Modules::MembershipEntity>, which has a method to retrieve Memberships and create an object for each of them. Error checking is handled in the latter module, so if you use this module directly you will have to do your own error checking, for example, to make sure that the Membership actually has at least one Term associated with it. (Yes, I know it should be impossible not to, but it happens. This is Drupal we are dealing with.)
 
-=head2 PARAMETERS
+=head2 CONSTRUCTOR PARAMETERS
 
 B<All parameters are required.> Consult the Drupal MembershipEntity documentation for more details.
 
