@@ -1,5 +1,5 @@
 package CMS::Drupal::Modules::MembershipEntity::Term;
-$CMS::Drupal::Modules::MembershipEntity::Term::VERSION = '0.91';
+$CMS::Drupal::Modules::MembershipEntity::Term::VERSION = '0.92';
 # ABSTRACT: Perl interface to a Drupal MembershipEntity membership term
 
 use strict;
@@ -26,14 +26,14 @@ sub is_active {
 sub is_current {
   my $self = shift;
   my $now = time;
-  return ($self->{'start'} <= $now && $now <= $self->{'end'})
+  return ( $self->{'start'} <= $now and $self->{'end'} > $now )
     ? 1 : 0;
 }
 
 sub is_future {
   my $self = shift;
   my $now = time;
-  return ($self->{'start'} > $now && $self->{'end'} > $self->{'start'})
+  return ($self->{'start'} > $now and $self->{'end'} > $self->{'start'})
     ? 1 : 0;
 }
 
@@ -57,7 +57,7 @@ CMS::Drupal::Modules::MembershipEntity::Term - Perl interface to a Drupal Member
 
 =head1 VERSION
 
-version 0.91
+version 0.92
 
 =head1 SYNOPSIS
 
@@ -98,7 +98,7 @@ Note: This module does not currently create or edit Membership Terms.
 
 This module is not designed to be called directly, although it can be. This module is called by L<CMS::Drupal::Modules::MembershipEntity>, which has a method that retrieves all Membership Terms and creates an object for each of them (which is stored inside the parent Membership object). Error checking is handled in the latter module, so if you use this module directly you will have to do your own error checking, for example, to make sure that the Term actually has a start and an end date-and-time associated with it. (Yes, I know it should be impossible not to, but it happens. This is Drupal we are dealing with.)
 
-=head2 PARAMETERS
+=head2 CONSTRUCTOR PARAMETERS
 
 B<All parameters are required.> Consult the Drupal MembershipEntity documentation for more details.
 
