@@ -1,17 +1,19 @@
 package CMS::Drupal::Modules::MembershipEntity::Test;
-$CMS::Drupal::Modules::MembershipEntity::Test::VERSION = '0.91';
+$CMS::Drupal::Modules::MembershipEntity::Test::VERSION = '0.92';
 # ABSTRACT: Exports some helper routines for testing
 
+use strict;
+use warnings;
+
 use base "Exporter::Tiny";
 our @EXPORT = qw/ build_test_db
                   build_and_validate_test_db
                   build_test_data /;
 
-use Data::Dumper;
 use Carp qw/ croak confess /;
 use Test::More;
 use Test::Group;
-use File::Slurp::Tiny qw/ read_file read_lines /;
+use File::Slurper qw/ read_text read_lines /;
 use FindBin;
 use Time::Local;
 
@@ -36,7 +38,7 @@ sub build_and_validate_test_db {
 
     subtest 'Created the test database tables.' => sub {
       plan tests => 4;
-      for (split( /\n{2,}/, read_file("$FindBin::Bin/data/test_db.sql") )) {
+      for (split( /\n{2,}/, read_text("$FindBin::Bin/data/test_db.sql") )) {
         my $rv = $dbh->do($_);
         isnt( $rv, undef, 'Added a table to the test database' );
       }   
@@ -51,7 +53,7 @@ sub build_and_validate_test_db {
       VALUES (?, ?, ?, ?, ?, ?, ?)
     /;
   
-    my @fields = split(',', read_file("$FindBin::Bin/data/test_types.dat")) or croak; # This file must have only ONE line
+    my @fields = split(',', read_text("$FindBin::Bin/data/test_types.dat")) or croak; # This file must have only ONE line
   
     my $add_type_rv = $dbh->do( $add_type, {}, @fields, undef );
     cmp_ok( $add_type_rv, '>', 0, 'Populate the membership_entity_type table with a default type' );
@@ -63,7 +65,7 @@ sub build_and_validate_test_db {
       /;
   
     test 'Populate the membership_entity table with test data' => sub {
-      for ( read_lines("$FindBin::Bin/data/test_memberships.dat",  chomp => 1 ) ) {
+      for ( read_lines("$FindBin::Bin/data/test_memberships.dat" ) ) {
         my @fields = split(',');
         my $add_mem_rv = $dbh->do( $add_mem, {}, @fields );
         cmp_ok( $add_mem_rv, '>', 0, "Added a Membership for mid $fields[0]" );
@@ -77,7 +79,7 @@ sub build_and_validate_test_db {
       /;
   
     test 'Populate the membership_entity_term table with test data' => sub {
-      for ( read_lines("$FindBin::Bin/data/test_terms.dat",  chomp => 1 ) ) {
+      for ( read_lines("$FindBin::Bin/data/test_terms.dat" ) ) {
         my @fields = split(',');
         my $add_term_rv = $dbh->do( $add_term, {}, @fields );
         cmp_ok( $add_term_rv, '>', 0, "Added a Term for $fields[0]" );
@@ -102,7 +104,7 @@ sub build_test_db {
   my $dbh = $drupal->dbh( database => ':memory:',
                           driver   => 'SQLite' );
 
-  for (split( /\n{2,}/, read_file("$FindBin::Bin/data/test_db.sql") )) {
+  for (split( /\n{2,}/, read_text("$FindBin::Bin/data/test_db.sql") )) {
     my $rv = $dbh->do($_);
   }
 
@@ -112,7 +114,7 @@ sub build_test_db {
     VALUES (?, ?, ?, ?, ?, ?, ?)
   /;
 
-  my @fields = split(',', read_file("$FindBin::Bin/data/test_types.dat")) or croak; # This file must have only ONE line
+  my @fields = split(',', read_text("$FindBin::Bin/data/test_types.dat")) or croak; # This file must have only ONE line
 
   my $add_type_rv = $dbh->do( $add_type, {}, @fields, undef );
 
@@ -122,7 +124,7 @@ sub build_test_db {
     VALUES ( ?, ?, ?, ?, ?, ?, ?)
     /;
 
-  for ( read_lines("$FindBin::Bin/data/test_memberships.dat",  chomp => 1 ) ) {
+  for ( read_lines("$FindBin::Bin/data/test_memberships.dat" ) ) {
     my @fields = split(',');
     my $add_mem_rv = $dbh->do( $add_mem, {}, @fields );
   }
@@ -133,7 +135,7 @@ sub build_test_db {
     VALUES (?, ?, ?, ?, ?, ?, ?)
     /;
 
-  for ( read_lines("$FindBin::Bin/data/test_terms.dat",  chomp => 1 ) ) {
+  for ( read_lines("$FindBin::Bin/data/test_terms.dat" ) ) {
     my @fields = split(',');
     my $add_term_rv = $dbh->do( $add_term, {}, @fields );
   }
@@ -147,18 +149,18 @@ sub build_test_db {
 
 sub build_test_data {
 
-  my $mids = shift;
+  my @mids = @_;
   my %include;
-  for( @$mids ) {
+  for( @mids ) {
     $include{ $_ }++;
   }
  
   my %membs;
   my %terms;
 
-  for ( read_lines("$FindBin::Bin/data/test_memberships.dat", chomp => 1) ) {
+  for ( read_lines("$FindBin::Bin/data/test_memberships.dat" ) ) {
     my @fields = split(',');
-    if (scalar @$mids > 0) { next unless exists $include{ $fields[0] }; }
+    if (scalar @mids > 0) { next unless exists $include{ $fields[0] }; }
     $membs{ $fields[0] } = { 'mid'       => $fields[0],
                              'member_id' => $fields[1],
                              'type'      => $fields[2],
@@ -170,9 +172,9 @@ sub build_test_data {
 
   my %term_count;
 
-  for ( read_lines("$FindBin::Bin/data/test_terms.dat", chomp => 1) ) {
+  for ( read_lines("$FindBin::Bin/data/test_terms.dat" ) ) {
     my @fields = split(',');
-    if (scalar @$mids > 0) { next unless exists $include{ $fields[1] } };
+    if (scalar @mids > 0) { next unless exists $include{ $fields[1] } };
     $term_count{ $fields[1] }++;
     for (5..6) {
       my @datetime = reverse (split /[-| |:]/, $fields[ $_ ]);
@@ -216,7 +218,7 @@ CMS::Drupal::Modules::MembershipEntity::Test - Exports some helper routines for
 
 =head1 VERSION
 
-version 0.91
+version 0.92
 
 =head1 SYNOPSIS
 
@@ -235,8 +237,8 @@ version 0.91
 
   # or:
  
-  my $hashref = $ME->fetch_memberships([ 1234, 5678 ]);
-  my $cmp_data = build_test_data([ 1234, 5678 ]);
+  my $hashref = $ME->fetch_memberships('1234', '5678');
+  my $cmp_data = build_test_data('1234', '5678');
 
   is_deeply($hashref, $cmp_data, 'Data matches'); 
 
@@ -293,11 +295,11 @@ This method returns a data structure containing the Memberships as they would be
 CMS::Drupal::Modules::MembershipEntity::fetch_memberships(). It creates the data structure
 by parsing the same files that were used to build in test database.
 
-The method takes an optional single argument, which is an arrayref containing a list of B<mid>s.
-Only the Memberships associated with the B<mid>s provided will; be included in the data
+The method takes an optional single argument, which is an array containing a list of B<mid>s.
+Only the Memberships associated with the B<mid>s provided will be included in the data
 returned.
 
-  $cmp_data = build_test_data( [ 1234, 5678 ] );
+  $cmp_data = build_test_data('1234', '5678');
 
 The data structure is a hashref of hashrefs (Membership objects, indexed by mid, containing
 among their attributes an array of hashrefs (Membership Term objects) ...
